# Murmur

> Package, publish, and manage AI agents and tools. 

Hi, thank you for checking out Murmur! Still work in progress 👨‍💻. 

Support us by starring the [:simple-github: murmur](https://github.com/murmur-nexus/murmur) repo.

I'd recommend checking out the [Getting Started with the Examples](tutorial/getting-started-with-examples.md) tutorial to get a feel for how it works.